==> netsurf_3.6.orig.tar.gz: netsurf-all-3.6/netsurf/content/handlers/javascript/none/none.c <==
/*
 * Copyright 2012 Vincent Sanders <vince@netsurf-browser.org>
 *
 * This file is part of NetSurf, http://www.netsurf-browser.org/
 *
 * NetSurf is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 2 of the License.
 *
 * NetSurf is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/** \file
 * Dummy implementation of javascript engine functions.
 */

#include "content/content.h"
#include "utils/nsoption.h"

#include "javascript/js.h"
#include "utils/log.h"

void js_initialise(void)
{
	nsoption_set_bool(enable_javascript, false);
}

void js_finalise(void)
{
}

nserror js_newcontext(int timeout, jscallback *cb, void *cbctx,
		jscontext **jsctx)
{
	*jsctx = NULL;
	return NSERROR_OK;
}

void js_destroycontext(jscontext *ctx)
{
}

jsobject *js_newcompartment(jscontext *ctx, void *win_priv, void *doc_priv)
{
	return NULL;
}

bool js_exec(jscontext *ctx, const char *txt, size_t txtlen)
{
	return true;
}

bool js_fire_event(jscontext *ctx, const char *type, struct dom_document *doc, struct dom_node *target)
{
	return true;
}

void js_handle_new_element(jscontext *ctx, struct dom_element *node)
{
}

void js_event_cleanup(jscontext *ctx, struct dom_event *evt)
{
}

==> netsurf_3.9.orig.tar.gz: netsurf-all-3.9/netsurf/content/handlers/javascript/none/none.c <==
/*
 * Copyright 2012 Vincent Sanders <vince@netsurf-browser.org>
 *
 * This file is part of NetSurf, http://www.netsurf-browser.org/
 *
 * NetSurf is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 2 of the License.
 *
 * NetSurf is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/** \file
 * Dummy implementation of javascript engine functions.
 */

#include "content/content.h"
#include "utils/nsoption.h"

#include "javascript/js.h"
#include "utils/log.h"

void js_initialise(void)
{
	nsoption_set_bool(enable_javascript, false);
}

void js_finalise(void)
{
}

nserror js_newcontext(int timeout, jscallback *cb, void *cbctx,
		jscontext **jsctx)
{
	*jsctx = NULL;
	return NSERROR_OK;
}

void js_destroycontext(jscontext *ctx)
{
}

jsobject *js_newcompartment(jscontext *ctx, void *win_priv, void *doc_priv)
{
	return NULL;
}

bool js_exec(jscontext *ctx, const uint8_t *txt, size_t txtlen, const char *name)
{
	return true;
}

bool js_fire_event(jscontext *ctx, const char *type, struct dom_document *doc, struct dom_node *target)
{
	return true;
}

void js_handle_new_element(jscontext *ctx, struct dom_element *node)
{
}

void js_event_cleanup(jscontext *ctx, struct dom_event *evt)
{
}
